from django.db import models
from django.utils.translation import gettext_lazy as _


# class MyModel(models.Model):
#
#     title = models.CharField(_('Title'), max_length=100, help_text=_('Description'))
#
#     class Meta:
#         verbose_name = _('Model')
#         verbose_name_plural = _('Models')
#
#     def __str__(self):
#         return self.title
